==> drowl_media-3.0.28.tar.gz: drowl_media/tests/src/Functional/DrowlMediaFunctionalTests.php <==
<?php

namespace Drupal\Tests\drowl_media\Functional;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\media\Entity\Media;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\media\Traits\MediaTypeCreationTrait;

/**
 * This class provides methods specifically for testing something.
 *
 * @group drowl_media
 */
class DrowlMediaFunctionalTests extends BrowserTestBase {
  use MediaTypeCreationTrait;
  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'drowl_media',
    'test_page_test',
    'blazy',
    'crop',
    'dropzonejs_eb_widget',
    'embed',
    'entity_browser',
    'entity_browser_entity_form',
    'entity_embed',
    'media_entity_file_replace',
    'fences',
    'field',
    'field_group',
    'file',
    'focal_point',
    'image',
    'inline_entity_form',
    'language',
    'link',
    'metatag',
    'node',
    'options',
    'path',
    'pathauto',
    'rabbit_hole',
    'responsive_image',
    'smart_trim',
    'taxonomy',
    'text',
    'user',
    'views',
    'views_linkarea',
    'viewsreference',
  ];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Creates a filed on an entity type bundle.
   *
   * @param Drupal\Core\Config\Entity\ConfigEntityInterface $entityTypeBundle
   *   The entity type bundle.
   * @param string $fieldName
   *   The field name.
   * @param array $fieldTypeSettings
   *   The field type settings.
   * @param int $cardinality
   *   The maximum number of values the field can hold. Possible values are
   *   positive integers or
   *   FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED. Defaults to 1.
   */
  protected function createFieldTypeOnEntityBundle(ConfigEntityInterface $entityTypeBundle, string $fieldName, array $fieldTypeSettings, $cardinality = 1) {
    $entityType = $entityTypeBundle->getEntityType()->id();
    $bundle = $entityTypeBundle->id();

    // FIXME: $entityType results are WRONG!
    // @todo Find the right way to get "node" instead of node_type
    // and "taxonomy_term" instead of "taxonomy_vocabulary".
    // SUPER Dirty workaround to remove _type - as we don't know how to
    // get it without the suffix... but we didn't have the time:
    $entityType = str_replace('_type', '', $entityType);
    if ($entityType == 'taxonomy_vocabulary') {
      $entityType = 'taxonomy_term';
    }

    // Create field:
    FieldStorageConfig::create([
      'field_name' => $fieldName,
      'entity_type' => $entityType,
      'type' => 'entity_reference',
      'cardinality' => $cardinality,
    ])->save();

    // Create field instance:
    FieldConfig::create([
      'field_name' => $fieldName,
      'entity_type' => $entityType,
      'bundle' => $bundle,
      'settings' => $fieldTypeSettings,
    ])->save();
    return $entityTypeBundle;
  }

  /**
   * Tests if the module installation, won't break the site.
   */
  public function testInstallation() {
    $session = $this->assertSession();
    $this->drupalGet('<front>');
    $session->statusCodeEquals(200);
  }

  /**
   * Tests if the media library exists in the header of the media overview.
   */
  public function testMediaLibraryExists() {
    $session = $this->assertSession();
    $this->drupalGet('/admin/content/media');
    $session->statusCodeEquals(200);
    $session->elementExists('css', 'head > link[href*=drowl_media]');
  }

  /**
   * Tests creation of a node with a media image reference field.
   */
  public function testCreateNodeWithMediaImagereferenceField() {
    $session = $this->assertSession();
    $contentType = $this->createContentType(['type' => 'article']);
    $media_type = $this->createMediaType('image');
    $media = Media::create([
      'bundle' => $media_type->id(),
      'name' => 'my_media',
    ]);
    $media->save();
    $this->createFieldTypeOnEntityBundle($contentType, 'field_test', []);
    $node = $this->createNode([
      'type' => 'article',
    ]);
    $this->drupalGet('/node/' . $node->getOriginalId());
    $session->statusCodeEquals(200);
  }

}

==> drowl_media-3.0.33.tar.gz: drowl_media/tests/src/Functional/DrowlMediaFunctionalTests.php <==
<?php

namespace Drupal\Tests\drowl_media\Functional;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\media\Entity\Media;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\media\Traits\MediaTypeCreationTrait;

/**
 * Tests drowl_media.
 *
 * @group drowl_media
 */
class DrowlMediaFunctionalTests extends BrowserTestBase {
  use MediaTypeCreationTrait;
  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'drowl_media',
    'test_page_test',
    'blazy',
    'crop',
    'dropzonejs_eb_widget',
    'embed',
    'entity_browser',
    'entity_browser_entity_form',
    'entity_embed',
    'media_entity_file_replace',
    'fences',
    'field',
    'field_group',
    'file',
    'focal_point',
    'image',
    'inline_entity_form',
    'language',
    'link',
    'metatag',
    'node',
    'options',
    'path',
    'pathauto',
    'rabbit_hole',
    'responsive_image',
    'smart_trim',
    'taxonomy',
    'text',
    'user',
    'views',
    'views_linkarea',
    'viewsreference',
  ];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests if the module installation, won't break the site.
   */
  public function testInstallation() {
    $session = $this->assertSession();
    $this->drupalGet('<front>');
    $session->statusCodeEquals(200);
  }

  /**
   * Tests if the drupal media library page is accessible.
   */
  public function testMediaLibraryExists() {
    $session = $this->assertSession();
    $this->drupalGet('/admin/content/media');
    $session->statusCodeEquals(200);
  }


/**
   * Tests if the media library exists in the header of the media overview.
   */
  public function testDrowlMediaLibraryAdminLibraryExists() {
    $session = $this->assertSession();
    $this->drupalGet('/admin/content/media');
    $session->statusCodeEquals(200);
    $session->elementExists('css', 'head > link[href*=drowl_media]');
  }
}
